patch "USB: added support for Cinterion's products AH6 and PLS8" added to usb tree

2013-03-06 Thread gregkh

This is a note to let you know that I've just added the patch titled

USB: added support for Cinterion's products AH6 and PLS8

to my usb git tree which can be found at
git://git.kernel.org/pub/scm/linux/kernel/git/gregkh/usb.git
in the usb-linus branch.

The patch will show up in the next release of the linux-next tree
(usually sometime within the next 24 hours during the week.)

The patch will hopefully also be merged in Linus's tree for the
next -rc kernel release.

If you have any questions about this process, please let me know.


>From 1941138e1c024ecb5bd797d414928d3eb94d8662 Mon Sep 17 00:00:00 2001
From: Christian Schmiedl 
Date: Wed, 6 Mar 2013 17:08:50 +0100
Subject: USB: added support for Cinterion's products AH6 and PLS8

add support for Cinterion's products AH6 and PLS8 by adding Product IDs
and USB_DEVICE tuples.

Signed-off-by: Christian Schmiedl 
Cc: stable 
Signed-off-by: Greg Kroah-Hartman 
---
 drivers/usb/serial/option.c | 4 
 1 file changed, 4 insertions(+)

diff --git a/drivers/usb/serial/option.c b/drivers/usb/serial/option.c
index b6266bd..558adfc 100644
--- a/drivers/usb/serial/option.c
+++ b/drivers/usb/serial/option.c
@@ -341,6 +341,8 @@ static void option_instat_callback(struct urb *urb);
 #define CINTERION_PRODUCT_EU3_E0x0051
 #define CINTERION_PRODUCT_EU3_P0x0052
 #define CINTERION_PRODUCT_PH8  0x0053
+#define CINTERION_PRODUCT_AH6  0x0055
+#define CINTERION_PRODUCT_PLS8 0x0060
 
 /* Olivetti products */
 #define OLIVETTI_VENDOR_ID 0x0b3c
@@ -1261,6 +1263,8 @@ static const struct usb_device_id option_ids[] = {
{ USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_EU3_E) },
{ USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_EU3_P) },
{ USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_PH8) },
+   { USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_AH6) },
+   { USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_PLS8) },
{ USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_HC28_MDM) }, 
{ USB_DEVICE(CINTERION_VENDOR_ID, CINTERION_PRODUCT_HC28_MDMNET) },
{ USB_DEVICE(SIEMENS_VENDOR_ID, CINTERION_PRODUCT_HC25_MDM) },
diff --git a/tools/usb/ffs-test.c b/tools/usb/ffs-test.c
index 8674b9e..fe1e66b 100644
--- a/tools/usb/ffs-test.c
+++ b/tools/usb/ffs-test.c
@@ -38,7 +38,7 @@
 #include 
 #include 
 
-#include "../../include/linux/usb/functionfs.h"
+#include "../../include/uapi/linux/usb/functionfs.h"
 
 
 / Little Endian Handling /
-- 
1.8.1.2.434.g9a6c84e.dirty


--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


patch "USB: option: add Huawei E5331" added to usb tree

2013-03-06 Thread gregkh

This is a note to let you know that I've just added the patch titled

USB: option: add Huawei E5331

to my usb git tree which can be found at
git://git.kernel.org/pub/scm/linux/kernel/git/gregkh/usb.git
in the usb-linus branch.

The patch will show up in the next release of the linux-next tree
(usually sometime within the next 24 hours during the week.)

The patch will hopefully also be merged in Linus's tree for the
next -rc kernel release.

If you have any questions about this process, please let me know.


>From daec90e7382cbd0e73eb6861109b3da91e5ab1f3 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Bj=C3=B8rn=20Mork?= 
Date: Wed, 27 Feb 2013 15:52:56 +0100
Subject: USB: option: add Huawei E5331
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

Another device using CDC ACM with vendor specific protocol to mark
serial functions.

Cc: stable 
Signed-off-by: Bjørn Mork 
Signed-off-by: Greg Kroah-Hartman 
---
 drivers/usb/serial/option.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/drivers/usb/serial/option.c b/drivers/usb/serial/option.c
index f7d339d..b6266bd 100644
--- a/drivers/usb/serial/option.c
+++ b/drivers/usb/serial/option.c
@@ -579,6 +579,7 @@ static const struct usb_device_id option_ids[] = {
{ USB_DEVICE(QUANTA_VENDOR_ID, 0xea42),
.driver_info = (kernel_ulong_t)&net_intf4_blacklist },
{ USB_DEVICE_AND_INTERFACE_INFO(HUAWEI_VENDOR_ID, 0x1c05, 
USB_CLASS_COMM, 0x02, 0xff) },
+   { USB_DEVICE_AND_INTERFACE_INFO(HUAWEI_VENDOR_ID, 0x1c1f, 
USB_CLASS_COMM, 0x02, 0xff) },
{ USB_DEVICE_AND_INTERFACE_INFO(HUAWEI_VENDOR_ID, 0x1c23, 
USB_CLASS_COMM, 0x02, 0xff) },
{ USB_DEVICE_AND_INTERFACE_INFO(HUAWEI_VENDOR_ID, HUAWEI_PRODUCT_E173, 
0xff, 0xff, 0xff),
.driver_info = (kernel_ulong_t) &net_intf1_blacklist },
-- 
1.8.1.2.434.g9a6c84e.dirty


--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: + dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present.patch added to -mm tree

2013-03-06 Thread Ben Hutchings
On Wed, 2013-03-06 at 16:07 +0800, Zhenzhong Duan wrote:
> On 2013-03-06 07:37, a...@linux-foundation.org wrote:
[...]
> > Subject: dmi_scan: fix missing check for _DMI_ signature in smbios_present()
> >
> > Commit 9f9c9cbb6057 ('drivers/firmware/dmi_scan.c: fetch dmi version from
> > SMBIOS if it exists') hoisted the check for "_DMI_" into
> > dmi_scan_machine(), which means that we don't bother to check for "_DMI_"
> > at offset 16 in an SMBIOS entry.  smbios_present() may also call
> > dmi_present() for an address where we found "_SM_", if it failed further
> > validation.
> >
> > Check for "_DMI_" in smbios_present() before calling dmi_present().
[...]
> > --- 
> > a/drivers/firmware/dmi_scan.c~dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present
> > +++ a/drivers/firmware/dmi_scan.c
> > @@ -442,7 +442,6 @@ static int __init dmi_present(const char
> >  static int __init smbios_present(const char __iomem *p)
> >  {
> > u8 buf[32];
> > -   int offset = 0;
> >  
> > memcpy_fromio(buf, p, 32);
> > if ((buf[5] < 32) && dmi_checksum(buf, buf[5])) {
> > @@ -461,9 +460,9 @@ static int __init smbios_present(const c
> > dmi_ver = 0x0206;
> > break;
> > }
> > -   offset = 16;
> > +   return memcmp(q + 16, "_DMI_", 5) || dmi_present(p + 16);
> > }
> 
> I remember H.J found a typo in this patch and the following patch.
> >The patch has a typo:
> >
> >-offset = 16;
> >+return memcmp(q + 16, "_DMI_", 5) || dmi_present(p + 16);
> > }
> >
> >'q' isn't defined here.  Change it to `p" also fixes the problem for me.
> >
> >H.J.
[...]

I don't know how I ended up sending this broken version rather than what
I actually tested.  Sorry about that.

Ben.

-- 
Ben Hutchings
Always try to do things in chronological order;
it's less confusing that way.


signature.asc
Description: This is a digitally signed message part


Re: 答复: [PATCH] USB: storage: fix Huawei mode switching regression

2013-03-06 Thread Greg KH
On Thu, Mar 07, 2013 at 02:54:38AM +, Fangxiaozhi (Franko) wrote:
> Dear All:
> As far as I know, except switching in kernel, there isn't any mode switch 
> solution on Android now.
> Do you have any good ideas for the mode switch on Android system?

Please discuss this with the Android developers, there's nothing that us
(the kernel community) can do about the Android userspace code, sorry.

Please work with Google to solve this properly there.

good luck,

greg k-h
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


RE: 答复: [PATCH] USB: storage: fix Huawei mode switching regression

2013-03-06 Thread Fangxiaozhi (Franko)
Dear All:
As far as I know, except switching in kernel, there isn't any mode 
switch solution on Android now.
Do you have any good ideas for the mode switch on Android system?
Best Regards,
Franko Fang
> -Original Message-
> From: Dan Williams [mailto:d...@redhat.com]
> Sent: Wednesday, March 06, 2013 11:46 PM
> To: Greg KH
> Cc: Linlei (Lei Lin); Bjørn Mork; linux-...@vger.kernel.org;
> linux-ker...@vger.kernel.org; Xueguiying (Zihan); Yili (Neil); Wangyuhua;
> Huqiao (C); ba...@ti.com; mdharm-...@one-eyed-alien.net;
> sebast...@breakpoint.cc; stable; Fangxiaozhi (Franko)
> Subject: Re: 答复: [PATCH] USB: storage: fix Huawei mode switching
> regression
> 
> On Wed, 2013-03-06 at 09:44 +0800, Greg KH wrote:
> > On Wed, Mar 06, 2013 at 01:34:44AM +, Linlei (Lei Lin) wrote:
> > > Hello Mork,
> > >
> > > >> -- Because in the embedded linux system, Android, or Chrome
> > > >> OS, etc. They don't integrate userspace usb_modeswitch utility
> > > >> for switching.
> > >
> > > >Why not?  If they can upgrade the kernel, then they most certainly can
> install a userspace utility.
> > >
> > > >There is no excuse for an embedded system to do this differently.
> > > >Please see e.g. OpenWRT as an example of an embedded system doing
> this correctly.
> > >
> > > But currently Android and Chrome OS has not integrated the
> > > usb_modeswitch utility.
> >
> > That is not a kernel problem.  I find it hard to believe that Chrome
> > OS would not gladly accept code to resolve this issue, can't you put
> > it into the modemmanager or whatever Chrome OS uses to handle their
> > wireless modems?
> 
> They use ModemManager, and that's still not the best place to put
> modeswitching.  The best place to modeswitch anything is usb_modeswitch.
> No sense duplicating the functionality that usb_modeswitch already supplies.
> 
> Dan
> 
> >
> > As for Android, sorry, you are on your own, you will just have to deal
> > with the individual OEMs that are incorporating your hardware :(
> >
> > > From a vendor's point of view, our purpose is to make our devices be
> > > supported natively by those OS.
> >
> > We have a solution, usb_modeswitch, any user should be using that.
> >
> > > So we consider that add the switch function to the kernel resolves
> > > the problem from the source.
> > > Then this function will be inherited by Android & Chrome OS.
> >
> > Don't circumvent horribly governed userspace projects by getting
> > changes into the Linux kernel.  Go fix those projects instead.
> >
> > Good luck,
> >
> > greg k-h
> > --
> > To unsubscribe from this list: send the line "unsubscribe linux-usb"
> > in the body of a message to majord...@vger.kernel.org More majordomo
> > info at  http://vger.kernel.org/majordomo-info.html
> 

N�r��yb�X��ǧv�^�)޺{.n�+��z)w*jg����ݢj/���z�ޖ��2�ޙ&�)ߡ�a�����G���h��j:+v���w��٥

[PATCH] gpio-sch: Allow for more than 8 lines in the resume well

2013-03-06 Thread Darren Hart
The E6xx (TunnelCreek) CPUs have 9 GPIO lines in the resume well. Update
the resume functions to allow for more than 8 GPIO lines, using the core
functions as a template.

Cc:  # 3.4.x
Cc:  # 3.8.x
Cc: Grant Likely 
Cc: Linus Walleij 
Signed-off-by: Darren Hart 
---
 drivers/gpio/gpio-sch.c | 37 +++--
 1 file changed, 27 insertions(+), 10 deletions(-)

diff --git a/drivers/gpio/gpio-sch.c b/drivers/gpio/gpio-sch.c
index edae963..7e7b52b 100644
--- a/drivers/gpio/gpio-sch.c
+++ b/drivers/gpio/gpio-sch.c
@@ -125,13 +125,17 @@ static int sch_gpio_resume_direction_in(struct gpio_chip 
*gc,
unsigned gpio_num)
 {
u8 curr_dirs;
+   unsigned short offset, bit;
 
spin_lock(&gpio_lock);
 
-   curr_dirs = inb(gpio_ba + RGIO);
+   offset = RGIO + gpio_num / 8;
+   bit = gpio_num % 8;
+
+   curr_dirs = inb(gpio_ba + offset);
 
-   if (!(curr_dirs & (1 << gpio_num)))
-   outb(curr_dirs | (1 << gpio_num) , gpio_ba + RGIO);
+   if (!(curr_dirs & (1 << bit)))
+   outb(curr_dirs | (1 << bit), gpio_ba + offset);
 
spin_unlock(&gpio_lock);
return 0;
@@ -139,22 +143,31 @@ static int sch_gpio_resume_direction_in(struct gpio_chip 
*gc,
 
 static int sch_gpio_resume_get(struct gpio_chip *gc, unsigned gpio_num)
 {
-   return !!(inb(gpio_ba + RGLV) & (1 << gpio_num));
+   unsigned short offset, bit;
+
+   offset = RGLV + gpio_num / 8;
+   bit = gpio_num % 8;
+
+   return !!(inb(gpio_ba + offset) & (1 << bit));
 }
 
 static void sch_gpio_resume_set(struct gpio_chip *gc,
unsigned gpio_num, int val)
 {
u8 curr_vals;
+   unsigned short offset, bit;
 
spin_lock(&gpio_lock);
 
-   curr_vals = inb(gpio_ba + RGLV);
+   offset = RGLV + gpio_num / 8;
+   bit = gpio_num % 8;
+
+   curr_vals = inb(gpio_ba + offset);
 
if (val)
-   outb(curr_vals | (1 << gpio_num), gpio_ba + RGLV);
+   outb(curr_vals | (1 << bit), gpio_ba + offset);
else
-   outb((curr_vals & ~(1 << gpio_num)), gpio_ba + RGLV);
+   outb((curr_vals & ~(1 << bit)), gpio_ba + offset);
 
spin_unlock(&gpio_lock);
 }
@@ -163,14 +176,18 @@ static int sch_gpio_resume_direction_out(struct gpio_chip 
*gc,
unsigned gpio_num, int val)
 {
u8 curr_dirs;
+   unsigned short offset, bit;
 
sch_gpio_resume_set(gc, gpio_num, val);
 
+   offset = RGIO + gpio_num / 8;
+   bit = gpio_num % 8;
+
spin_lock(&gpio_lock);
 
-   curr_dirs = inb(gpio_ba + RGIO);
-   if (curr_dirs & (1 << gpio_num))
-   outb(curr_dirs & ~(1 << gpio_num), gpio_ba + RGIO);
+   curr_dirs = inb(gpio_ba + offset);
+   if (curr_dirs & (1 << bit))
+   outb(curr_dirs & ~(1 << bit), gpio_ba + offset);
 
spin_unlock(&gpio_lock);
return 0;
-- 
1.8.1.2

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


+ dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix.patch added to -mm tree

2013-03-06 Thread akpm

The patch titled
 Subject: 
dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix
has been added to the -mm tree.  Its filename is
 dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix.patch

Before you just go and hit "reply", please:
   a) Consider who else should be cc'ed
   b) Prefer to cc a suitable mailing list as well
   c) Ideally: find the original patch on the mailing list and do a
  reply-to-all to that, adding suitable additional cc's

*** Remember to use Documentation/SubmitChecklist when testing your code ***

The -mm tree is included into linux-next and is updated
there every 3-4 working days

--
From: Andrew Morton 
Subject: dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix

Cc: 
Cc: Ben Hutchings 
Cc: Tim McGrath 
Cc: Zhenzhong Duan 
Signed-off-by: Andrew Morton 
---

 drivers/firmware/dmi_scan.c |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff -puN 
drivers/firmware/dmi_scan.c~dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix
 drivers/firmware/dmi_scan.c
--- 
a/drivers/firmware/dmi_scan.c~dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix
+++ a/drivers/firmware/dmi_scan.c
@@ -460,7 +460,7 @@ static int __init smbios_present(const c
dmi_ver = 0x0206;
break;
}
-   return memcmp(q + 16, "_DMI_", 5) || dmi_present(p + 16);
+   return memcmp(p + 16, "_DMI_", 5) || dmi_present(p + 16);
}
return 1;
 }
_

Patches currently in -mm which might be from a...@linux-foundation.org are

linux-next.patch
linux-next-git-rejects.patch
arch-alpha-kernel-systblss-remove-debug-check.patch
i-need-old-gcc.patch
dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present-fix.patch
timer_list-convert-timer-list-to-be-a-proper-seq_file.patch
timer_list-convert-timer-list-to-be-a-proper-seq_file-v3-fix.patch
mm.patch
mm-shmemc-remove-an-ifdef.patch
include-linux-mmzoneh-cleanups.patch
include-linux-mmzoneh-cleanups-fix.patch
drop_caches-add-some-documentation-and-info-messsge.patch
memcg-debugging-facility-to-access-dangling-memcgs-fix.patch
kernel-smpc-cleanups.patch
binfmt_elfc-use-get_random_int-to-fix-entropy-depleting.patch
rtc-ds1307-long-block-operations-bugfix.patch
kexec-use-min_t-to-simplify-logic-fix.patch
aio-kiocb_cancel-fix.patch
wait-add-wait_event_hrtimeout-fix.patch
aio-use-cancellation-list-lazily-fix-fix.patch
aio-give-shared-kioctx-fields-their-own-cachelines-fix.patch
generic-dynamic-per-cpu-refcounting-fix.patch
generic-dynamic-per-cpu-refcounting-sparse-fixes-fix.patch
generic-dynamic-per-cpu-refcounting-doc-fix.patch
aio-dont-include-aioh-in-schedh-fix.patch
aio-dont-include-aioh-in-schedh-fix-fix.patch
aio-dont-include-aioh-in-schedh-fix-3.patch
aio-dont-include-aioh-in-schedh-fix-3-fix.patch
aio-dont-include-aioh-in-schedh-fix-3-fix-fix.patch
aio-kill-ki_retry-fix.patch
block-aio-batch-completion-for-bios-kiocbs-fix.patch
block-aio-batch-completion-for-bios-kiocbs-fix-fix.patch
block-aio-batch-completion-for-bios-kiocbs-fix-fix-fix.patch
block-aio-batch-completion-for-bios-kiocbs-fix-fix-fix-fix-fix-fix.patch
debugging-keep-track-of-page-owners-fix-2-fix.patch
debugging-keep-track-of-page-owners-fix-2-fix-fix-fix.patch
journal_add_journal_head-debug.patch
kernel-forkc-export-kernel_thread-to-modules.patch
mutex-subsystem-synchro-test-module.patch
slab-leaks3-default-y.patch
put_bh-debug.patch

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH v2] arm: davinci: fix edma dmaengine induced null pointer dereference on da830

2013-03-06 Thread Tomas Novotny
On Tue,  5 Mar 2013 10:58:22 -0500
Matt Porter  wrote:

> This adds additional error checking to the private edma api implementation
> to catch the case where the edma_alloc_slot() has an invalid controller
> parameter. The edma dmaengine wrapper driver relies on this condition
> being handled in order to avoid setting up a second edma dmaengine
> instance on DA830.
> 
> Verfied using a DA850 with the second EDMA controller platform instance
> removed to simulate a DA830 which only has a single EDMA controller.
> 
> Reported-by: Tomas Novotny 
> Signed-off-by: Matt Porter 
> Cc: stable@vger.kernel.org # v3.7.x+
> ---
> v2: Move error check out of conditional to catch all cases
> 
>  arch/arm/mach-davinci/dma.c |3 +++
>  1 file changed, 3 insertions(+)
> 
> diff --git a/arch/arm/mach-davinci/dma.c b/arch/arm/mach-davinci/dma.c
> index a685e97..45b7c71 100644
> --- a/arch/arm/mach-davinci/dma.c
> +++ b/arch/arm/mach-davinci/dma.c
> @@ -743,6 +743,9 @@ EXPORT_SYMBOL(edma_free_channel);
>   */
>  int edma_alloc_slot(unsigned ctlr, int slot)
>  {
> + if (!edma_cc[ctlr])
> + return -EINVAL;
> +
>   if (slot >= 0)
>   slot = EDMA_CHAN_SLOT(slot);
>  

On the TI AM1707 based custom board:

Tested-by: Tomas Novotny 
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: rtsx: SD card is not recognized when booting system with it inserted

2013-03-06 Thread Tim Gardner
On 03/06/2013 08:38 AM, Luis Henriques wrote:
> On Wed, Mar 06, 2013 at 06:56:01AM -0700, Tim Gardner wrote:
>> Please consider the following for 3.5.y and newer.
>>
>> 504decc0a063e6a09a1e5b203ca68bc21dfffde9 mfd: rtsx: Optimize card
>> detect flow
>> c3481955f6c78c8dd99921759306d7469c999ec2 mfd: rtsx: Fix issue that
>> booting OS with SD card inserted
>>
>> Tested on 3.5 and 3.8.
> 
> Thanks, I'll queue it for 3.5 kernel.
> 
> Cheers,
> --
> Luis
> 
>>
>> http://bugs.launchpad.net/bugs/1148892
>>
>> rtg
>> -- 
>> Tim Gardner tim.gard...@canonical.com
>> --
>> To unsubscribe from this list: send the line "unsubscribe stable" in
>> the body of a message to majord...@vger.kernel.org
>> More majordomo info at  http://vger.kernel.org/majordomo-info.html

Doh! Forgot I had Ubuntu cruft in my kernel. These commits really only
apply to 3.8.

rtg
-- 
Tim Gardner tim.gard...@canonical.com
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH 3.8 stable] x86/kvm: Fix pvclock vsyscall fixmap

2013-03-06 Thread Gleb Natapov
From: Peter Hurley 

The physical memory fixmapped for the pvclock clock_gettime vsyscall
was allocated, and thus is not a kernel symbol. __pa() is the proper
method to use in this case.

Fixes the crash below when booting a next-20130204+ smp guest on a
3.8-rc5+ KVM host.

[0.666410] udevd[97]: starting version 175
[0.674043] udevd[97]: udevd:[97]: segfault at ff5fd020
 ip 7fff069e277f sp 7fff068c9ef8 error d

Acked-by: Marcelo Tosatti 
Signed-off-by: Peter Hurley 
Signed-off-by: Gleb Natapov 
(cherry picked from commit 3d2a80a230250c2534ce5b17503670adaf1d7fff)
---
 arch/x86/kernel/pvclock.c |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/arch/x86/kernel/pvclock.c b/arch/x86/kernel/pvclock.c
index 85c3959..2cb9470 100644
--- a/arch/x86/kernel/pvclock.c
+++ b/arch/x86/kernel/pvclock.c
@@ -185,7 +185,7 @@ int __init pvclock_init_vsyscall(struct 
pvclock_vsyscall_time_info *i,
 
for (idx = 0; idx <= (PVCLOCK_FIXMAP_END-PVCLOCK_FIXMAP_BEGIN); idx++) {
__set_fixmap(PVCLOCK_FIXMAP_BEGIN + idx,
-__pa_symbol(i) + (idx*PAGE_SIZE),
+__pa(i) + (idx*PAGE_SIZE),
 PAGE_KERNEL_VVAR);
}
 
-- 
1.7.10.4

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: 答复: [PATCH] USB: storage: fix Huawei mode switching regression

2013-03-06 Thread Dan Williams
On Wed, 2013-03-06 at 09:44 +0800, Greg KH wrote:
> On Wed, Mar 06, 2013 at 01:34:44AM +, Linlei (Lei Lin) wrote:
> > Hello Mork,
> > 
> > >> -- Because in the embedded linux system, Android, or Chrome OS, 
> > >> etc. They don't integrate userspace usb_modeswitch utility for 
> > >> switching.
> > 
> > >Why not?  If they can upgrade the kernel, then they most certainly can 
> > >install a userspace utility.
> > 
> > >There is no excuse for an embedded system to do this differently.
> > >Please see e.g. OpenWRT as an example of an embedded system doing this 
> > >correctly.
> > 
> > But currently Android and Chrome OS has not integrated the
> > usb_modeswitch utility.
> 
> That is not a kernel problem.  I find it hard to believe that Chrome OS
> would not gladly accept code to resolve this issue, can't you put it
> into the modemmanager or whatever Chrome OS uses to handle their
> wireless modems?

They use ModemManager, and that's still not the best place to put
modeswitching.  The best place to modeswitch anything is usb_modeswitch.
No sense duplicating the functionality that usb_modeswitch already
supplies.

Dan

> 
> As for Android, sorry, you are on your own, you will just have to deal
> with the individual OEMs that are incorporating your hardware :(
> 
> > From a vendor's point of view, our purpose is to make our devices be
> > supported natively by those OS.
> 
> We have a solution, usb_modeswitch, any user should be using that.
> 
> > So we consider that add the switch function to the kernel resolves the
> > problem from the source.
> > Then this function will be inherited by Android & Chrome OS.
> 
> Don't circumvent horribly governed userspace projects by getting changes
> into the Linux kernel.  Go fix those projects instead.
> 
> Good luck,
> 
> greg k-h
> --
> To unsubscribe from this list: send the line "unsubscribe linux-usb" in
> the body of a message to majord...@vger.kernel.org
> More majordomo info at  http://vger.kernel.org/majordomo-info.html


--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: rtsx: SD card is not recognized when booting system with it inserted

2013-03-06 Thread Luis Henriques
On Wed, Mar 06, 2013 at 06:56:01AM -0700, Tim Gardner wrote:
> Please consider the following for 3.5.y and newer.
> 
> 504decc0a063e6a09a1e5b203ca68bc21dfffde9 mfd: rtsx: Optimize card
> detect flow
> c3481955f6c78c8dd99921759306d7469c999ec2 mfd: rtsx: Fix issue that
> booting OS with SD card inserted
> 
> Tested on 3.5 and 3.8.

Thanks, I'll queue it for 3.5 kernel.

Cheers,
--
Luis

> 
> http://bugs.launchpad.net/bugs/1148892
> 
> rtg
> -- 
> Tim Gardner tim.gard...@canonical.com
> --
> To unsubscribe from this list: send the line "unsubscribe stable" in
> the body of a message to majord...@vger.kernel.org
> More majordomo info at  http://vger.kernel.org/majordomo-info.html
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH] CIFS: Fix missing of oplock_read value in smb30_values structure

2013-03-06 Thread Pavel Shilovsky
Cc: stable@vger.kernel.org
Signed-off-by: Pavel Shilovsky 
---
 fs/cifs/smb2ops.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/fs/cifs/smb2ops.c b/fs/cifs/smb2ops.c
index dc38434..22aef1d 100644
--- a/fs/cifs/smb2ops.c
+++ b/fs/cifs/smb2ops.c
@@ -746,4 +746,5 @@ struct smb_version_values smb30_values = {
.cap_unix = 0,
.cap_nt_find = SMB2_NT_FIND,
.cap_large_files = SMB2_LARGE_FILES,
+   .oplock_read = SMB2_OPLOCK_LEVEL_II,
 };
-- 
1.8.1.5

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH 3.8] mac80211: prevent spurious HT/VHT downgrade message

2013-03-06 Thread Johannes Berg
From: Johannes Berg 

Commit 586e01ededf9b713a1512dd658806791a7ca1a50 upstream.

Even when connecting to an AP that doesn't support VHT,
and even when the local device doesn't support it either,
the downgrade message gets printed. Suppress the message
if HT and/or VHT is disabled.

Signed-off-by: Johannes Berg 
---
 net/mac80211/mlme.c | 4 
 1 file changed, 4 insertions(+)

diff --git a/net/mac80211/mlme.c b/net/mac80211/mlme.c
index 5107248..55a7fdd 100644
--- a/net/mac80211/mlme.c
+++ b/net/mac80211/mlme.c
@@ -3401,6 +3401,10 @@ ieee80211_determine_chantype(struct 
ieee80211_sub_if_data *sdata,
ret = 0;
 
 out:
+   /* don't print the message below for VHT mismatch if VHT is disabled */
+   if (ret & IEEE80211_STA_DISABLE_VHT)
+   vht_chandef = *chandef;
+
while (!cfg80211_chandef_usable(sdata->local->hw.wiphy, chandef,
IEEE80211_CHAN_DISABLED)) {
if (WARN_ON(chandef->width == NL80211_CHAN_WIDTH_20_NOHT)) {
-- 
1.8.0

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: 2.6.32.y and Revert "block: improve queue_should_plug() by looking at IO depths"

2013-03-06 Thread Thomas Bork

On 05.03.2013 08:42, Willy Tarreau wrote:


If you want to make any backport, please keep the original patch format
with the commit description and add your signed-off-by at the bottom so
that we keep the workflow intact. And for each patch that is either in
mainline or in another stable branch, please report the original commit
ID in the patch's description. That helps a lot to know whether we are
affected when a regression is reported for this patch.


Sorry for that. Attached the patch with description.

Thank you.

--
der tom
>From 79da0644a8e0838522828f106e4049639eea6baf Mon Sep 17 00:00:00 2001
From: Jens Axboe 
Date: Tue, 23 Feb 2010 07:40:43 +
Subject: Revert "block: improve queue_should_plug() by looking at IO depths"

This reverts commit fb1e75389bd06fd5987e9cda1b4e0305c782f854.

"Benjamin S."  reports that the patch in question
causes a big drop in sequential throughput for him, dropping from
200MB/sec down to only 70MB/sec.

Needs to be investigated more fully, for now lets just revert the
offending commit.

Conflicts:

	include/linux/blkdev.h

Backported to 2.6.32.y.
2.6.33.y and following kernel versions have this fix.

Signed-off-by: Jens Axboe 
Signed-off-by: Thomas Bork 
---
--- linux-2.6.32.60.org/block/blk-core.c	2012-10-07 23:41:24.0 +0200
+++ linux-2.6.32.60/block/blk-core.c	2013-03-04 21:29:07.0 +0100
@@ -1149,7 +1149,7 @@ void init_request_from_bio(struct reques
  */
 static inline bool queue_should_plug(struct request_queue *q)
 {
-	return !(blk_queue_nonrot(q) && blk_queue_queuing(q));
+	return !(blk_queue_nonrot(q) && blk_queue_tagged(q));
 }
 
 static int __make_request(struct request_queue *q, struct bio *bio)
@@ -1861,15 +1861,8 @@ void blk_dequeue_request(struct request
 	 * and to it is freed is accounted as io that is in progress at
 	 * the driver side.
 	 */
-	if (blk_account_rq(rq)) {
+	if (blk_account_rq(rq))
 		q->in_flight[rq_is_sync(rq)]++;
-		/*
-		 * Mark this device as supporting hardware queuing, if
-		 * we have more IOs in flight than 4.
-		 */
-		if (!blk_queue_queuing(q) && queue_in_flight(q) > 4)
-			set_bit(QUEUE_FLAG_CQ, &q->queue_flags);
-	}
 }
 
 /**
--- linux-2.6.32.60.org/include/linux/blkdev.h	2012-10-07 23:41:24.0 +0200
+++ linux-2.6.32.60/include/linux/blkdev.h	2013-03-04 21:29:07.0 +0100
@@ -456,8 +456,7 @@ struct request_queue
 #define QUEUE_FLAG_NONROT  14	/* non-rotational device (SSD) */
 #define QUEUE_FLAG_VIRTQUEUE_FLAG_NONROT /* paravirt device */
 #define QUEUE_FLAG_IO_STAT 15	/* do IO stats */
-#define QUEUE_FLAG_CQ	   16	/* hardware does queuing */
-#define QUEUE_FLAG_DISCARD 17	/* supports DISCARD */
+#define QUEUE_FLAG_DISCARD 16	/* supports DISCARD */
 
 #define QUEUE_FLAG_DEFAULT	((1 << QUEUE_FLAG_IO_STAT) |		\
  (1 << QUEUE_FLAG_STACKABLE)	|	\
@@ -580,7 +579,6 @@ enum {
 
 #define blk_queue_plugged(q)	test_bit(QUEUE_FLAG_PLUGGED, &(q)->queue_flags)
 #define blk_queue_tagged(q)	test_bit(QUEUE_FLAG_QUEUED, &(q)->queue_flags)
-#define blk_queue_queuing(q)	test_bit(QUEUE_FLAG_CQ, &(q)->queue_flags)
 #define blk_queue_stopped(q)	test_bit(QUEUE_FLAG_STOPPED, &(q)->queue_flags)
 #define blk_queue_nomerges(q)	test_bit(QUEUE_FLAG_NOMERGES, &(q)->queue_flags)
 #define blk_queue_nonrot(q)	test_bit(QUEUE_FLAG_NONROT, &(q)->queue_flags)


Re: [PATCH] tty/8250_pnp: serial port detection regression since v3.7

2013-03-06 Thread Vincent Deffontaines

Le 2013-03-04 14:28, Sean Young a écrit :

Greg,

On Fri, Feb 22, 2013 at 04:27:19PM +, Sean Young wrote:

The InsydeH2O BIOS (version dated 09/12/2011) has the following in
its pnp resouces for its serial ports:

$ cat /sys/bus/pnp/devices/00:0b/resources
state = active
io disabled
irq disabled

We do not check if the resources are disabled, and create a bogus
ttyS* device. Since commit 835d844d1a28e (8250_pnp: do pnp probe
before legacy probe) we get a bogus ttyS0, which prevents the legacy
probe from detecting it.


Would you mind accepting this patch please -- it fixes a regression I
introduced in 3.7.



Hi Sean,

Thanks for the patch, and thanks for re-pushing it :)
This is to inform you that the BIOS update referenced :
Version: SC24 BIOS V1.01
Release Date: 01/11/2013

Seems to fix "my" tty detection problem on 3.7 (tested on a 3.7.6 
Fedora kernel, with success).
I don't think the patch will hurt anyway - I believe it still will 
prevent other users from a regression.
I also confirm that the patched 3.8.0 detects its ttys fine on a 
BIOS-updated system.


Regards,

Vincent


--
Stop chasing shadows, just enjoy the ride
Morcheeba

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


rtsx: SD card is not recognized when booting system with it inserted

2013-03-06 Thread Tim Gardner

Please consider the following for 3.5.y and newer.

504decc0a063e6a09a1e5b203ca68bc21dfffde9 mfd: rtsx: Optimize card detect 
flow
c3481955f6c78c8dd99921759306d7469c999ec2 mfd: rtsx: Fix issue that 
booting OS with SD card inserted


Tested on 3.5 and 3.8.

http://bugs.launchpad.net/bugs/1148892

rtg
--
Tim Gardner tim.gard...@canonical.com
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Linux 3.2.40

2013-03-06 Thread Ben Hutchings
I'm announcing the release of the 3.2.40 kernel.

All users of the 3.2 kernel series should upgrade.

The updated 3.2.y git tree can be found at:
git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux-stable.git 
linux-3.2.y
and can be browsed at the normal kernel.org git web browser:
http://git.kernel.org/?p=linux/kernel/git/stable/linux-stable.git

Ben.



 Documentation/kernel-parameters.txt  |5 +
 Makefile |2 +-
 arch/arm/mach-pxa/include/mach/smemc.h   |1 +
 arch/arm/mach-pxa/smemc.c|   15 +-
 arch/arm/mach-s3c2410/include/mach/debug-macro.S |   12 +-
 arch/arm/mach-s3c2410/include/mach/entry-macro.S |4 +-
 arch/arm/mach-s3c2410/pm-h1940.S |2 +-
 arch/arm/mach-s3c2410/sleep.S|   12 +-
 arch/arm/mach-s3c2412/sleep.S|   12 +-
 arch/arm/mach-w90x900/include/mach/entry-macro.S |4 +-
 arch/arm/plat-samsung/include/plat/debug-macro.S |   18 +-
 arch/parisc/include/asm/pgtable.h|   13 +-
 arch/parisc/kernel/cache.c   |   18 ++
 arch/powerpc/include/asm/eeh.h   |3 +
 arch/powerpc/kernel/machine_kexec_64.c   |5 +
 arch/powerpc/kernel/of_platform.c|3 +
 arch/powerpc/kernel/pci-common.c |7 +-
 arch/powerpc/platforms/pseries/eeh.c |   24 ++-
 arch/s390/kernel/time.c  |3 +
 arch/s390/kvm/kvm-s390.c |8 +
 arch/x86/Kconfig |2 +-
 arch/x86/include/asm/pgtable.h   |5 +
 arch/x86/kernel/apic/x2apic_phys.c   |   17 +-
 arch/x86/kernel/cpu/mshyperv.c   |3 +-
 arch/x86/kernel/head.c   |   53 +++--
 arch/x86/mm/fault.c  |8 +-
 arch/x86/mm/init_64.c|3 +
 arch/x86/platform/efi/efi.c  |   59 +++---
 arch/x86/xen/spinlock.c  |1 -
 block/genhd.c|   15 +-
 drivers/acpi/sleep.c |8 +
 drivers/ata/ata_piix.c   |   35 
 drivers/base/bus.c   |4 +-
 drivers/block/nbd.c  |   10 +
 drivers/block/sunvdc.c   |2 +-
 drivers/block/xen-blkback/xenbus.c   |   49 +++--
 drivers/dca/dca-core.c   |5 +
 drivers/firewire/core-device.c   |4 +
 drivers/gpu/drm/drm_edid.c   |6 +-
 drivers/gpu/drm/drm_usb.c|2 +-
 drivers/gpu/drm/i915/i915_debugfs.c  |2 +-
 drivers/gpu/drm/i915/intel_display.c |   12 +-
 drivers/gpu/drm/radeon/evergreen.c   |2 +
 drivers/hid/hid-core.c   |1 +
 drivers/hid/hid-ids.h|3 +
 drivers/iommu/intel-iommu.c  |8 +-
 drivers/media/rc/rc-main.c   |5 +-
 drivers/media/video/omap/omap_vout.c |   12 +-
 drivers/media/video/v4l2-device.c|   30 ++-
 drivers/mmc/host/sdhci-esdhc-imx.c   |   19 +-
 drivers/net/ethernet/intel/igb/igb_main.c|8 +-
 drivers/net/wireless/b43/dma.h   |2 +-
 drivers/net/wireless/p54/p54usb.c|2 +-
 drivers/net/wireless/rtlwifi/rtl8192cu/sw.c  |9 +-
 drivers/net/wireless/rtlwifi/usb.c   |   49 +++--
 drivers/net/wireless/rtlwifi/usb.h   |3 +-
 drivers/net/xen-netback/interface.c  |3 +-
 drivers/net/xen-netback/netback.c|8 +-
 drivers/pci/remove.c |2 +
 drivers/pcmcia/vrc4171_card.c|1 +
 drivers/platform/x86/asus-laptop.c   |   17 +-
 drivers/pps/clients/pps-ldisc.c  |   10 +-
 drivers/pps/pps.c|   47 -
 drivers/rtc/rtc-pl031.c  |4 +-
 drivers/s390/kvm/kvm_virtio.c|   38 +++-
 drivers/staging/comedi/comedi_fops.c |   13 +-
 drivers/staging/comedi/drivers/ni_labpc.c|   35 ++--
 drivers/staging/speakup/speakup_soft.c   |2 +-
 drivers/staging/zram/zram_drv.c  |4 +-
 drivers/target/target_core_device.c  |   13 +-
 drivers/target/target_core_fabric_configfs.c |   12 +-
 drivers/target/target_core_tpg.c |   10 +-
 drivers/tty/serial/8250.c|4 +-
 drivers/tty/tty_ioctl.c  |4 +-
 drivers/tty/vt/vt.c  |  136 
 drivers/usb/core/driver.c|   38 ++--
 drivers/usb/core/hub.c  

[PATCH v2] usb: musb: da8xx: Fix build breakage due to typo

2013-03-06 Thread Michael Riesch
From: Mikhail Kshevetskiy 

Commit 032ec49f5351e9cb242b1a1c367d14415043ab95 (usb: musb: drop useless
board_mode usage) introduced a typo that breaks the build.

Signed-off-by: Mikhail Kshevetskiy 
[Fixed commit message]
Signed-off-by: Michael Riesch 
Cc: Mikhail Kshevetskiy 
Cc: Sergei Shtylyov 
Cc: Felipe Balbi 
Cc: stable@vger.kernel.org
---

Changes for v2:
- Fixed commit message

 drivers/usb/musb/da8xx.c |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/usb/musb/da8xx.c b/drivers/usb/musb/da8xx.c
index 97996af..8749c2b 100644
--- a/drivers/usb/musb/da8xx.c
+++ b/drivers/usb/musb/da8xx.c
@@ -327,7 +327,7 @@ static irqreturn_t da8xx_musb_interrupt(int irq, void *hci)
u8 devctl = musb_readb(mregs, MUSB_DEVCTL);
int err;
 
-   err = musb->int_usb & USB_INTR_VBUSERROR;
+   err = musb->int_usb & MUSB_INTR_VBUSERROR;
if (err) {
/*
 * The Mentor core doesn't debounce VBUS as needed
-- 
1.8.1.2.434.g9a6c84e.dirty


--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


patch "USB: storage: fix Huawei mode switching regression" added to usb tree

2013-03-06 Thread gregkh

This is a note to let you know that I've just added the patch titled

USB: storage: fix Huawei mode switching regression

to my usb git tree which can be found at
git://git.kernel.org/pub/scm/linux/kernel/git/gregkh/usb.git
in the usb-linus branch.

The patch will show up in the next release of the linux-next tree
(usually sometime within the next 24 hours during the week.)

The patch will hopefully also be merged in Linus's tree for the
next -rc kernel release.

If you have any questions about this process, please let me know.


>From ab4b71644a26d1ab92b987b2fd30e17c25e89f85 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Bj=C3=B8rn=20Mork?= 
Date: Mon, 4 Mar 2013 14:19:21 +0100
Subject: USB: storage: fix Huawei mode switching regression
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

This reverts commit 200e0d99 ("USB: storage: optimize to match the
Huawei USB storage devices and support new switch command" and the
followup bugfix commit cd060956 ("USB: storage: properly handle
the endian issues of idProduct").

The commit effectively added a large number of Huawei devices to
the deprecated usb-storage mode switching logic.  Many of these
devices have been in use and supported by the userspace
usb_modeswitch utility for years.  Forcing the switching inside
the kernel causes a number of regressions as a result of ignoring
existing onfigurations, and also completely takes away the ability
to configure mode switching per device/system/user.

Known regressions caused by this:
 - Some of the devices support multiple modes, using different
  switching commands.  There are existing configurations taking
  advantage of this.

 - There is a real use case for disabling mode switching and
  instead mounting the exposed storage device. This becomes
  impossible with switching logic inside the usb-storage driver.

 - At least on device fail as a result of the usb-storage switching
  command, becoming completely unswitchable. This is possibly a
  firmware bug, but still a regression because the device work as
  expected using usb_modeswitch defaults.

In-kernel mode switching was deprecated years ago with the
development of the more user friendly userspace alternatives. The
existing list of devices in usb-storage was only kept to prevent
breaking already working systems.  The long term plan is to remove
the list, not to add to it. Ref:
http://permalink.gmane.org/gmane.linux.usb.general/28543

Cc: 
Cc: stable 
Signed-off-by: Bjørn Mork 
Signed-off-by: Greg Kroah-Hartman 
---
 drivers/usb/storage/initializers.c |  76 +
 drivers/usb/storage/initializers.h |   4 +-
 drivers/usb/storage/unusual_devs.h | 329 -
 3 files changed, 331 insertions(+), 78 deletions(-)

diff --git a/drivers/usb/storage/initializers.c 
b/drivers/usb/storage/initializers.c
index 7ab9046..105d900 100644
--- a/drivers/usb/storage/initializers.c
+++ b/drivers/usb/storage/initializers.c
@@ -92,8 +92,8 @@ int usb_stor_ucr61s2b_init(struct us_data *us)
return 0;
 }
 
-/* This places the HUAWEI usb dongles in multi-port mode */
-static int usb_stor_huawei_feature_init(struct us_data *us)
+/* This places the HUAWEI E220 devices in multi-port mode */
+int usb_stor_huawei_e220_init(struct us_data *us)
 {
int result;
 
@@ -104,75 +104,3 @@ static int usb_stor_huawei_feature_init(struct us_data *us)
US_DEBUGP("Huawei mode set result is %d\n", result);
return 0;
 }
-
-/*
- * It will send a scsi switch command called rewind' to huawei dongle.
- * When the dongle receives this command at the first time,
- * it will reboot immediately. After rebooted, it will ignore this command.
- * So it is  unnecessary to read its response.
- */
-static int usb_stor_huawei_scsi_init(struct us_data *us)
-{
-   int result = 0;
-   int act_len = 0;
-   struct bulk_cb_wrap *bcbw = (struct bulk_cb_wrap *) us->iobuf;
-   char rewind_cmd[] = {0x11, 0x06, 0x20, 0x00, 0x00, 0x01, 0x01, 0x00,
-   0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
-
-   bcbw->Signature = cpu_to_le32(US_BULK_CB_SIGN);
-   bcbw->Tag = 0;
-   bcbw->DataTransferLength = 0;
-   bcbw->Flags = bcbw->Lun = 0;
-   bcbw->Length = sizeof(rewind_cmd);
-   memset(bcbw->CDB, 0, sizeof(bcbw->CDB));
-   memcpy(bcbw->CDB, rewind_cmd, sizeof(rewind_cmd));
-
-   result = usb_stor_bulk_transfer_buf(us, us->send_bulk_pipe, bcbw,
-   US_BULK_CB_WRAP_LEN, &act_len);
-   US_DEBUGP("transfer actual length=%d, result=%d\n", act_len, result);
-   return result;
-}
-
-/*
- * It tries to find the supported Huawei USB dongles.
- * In Huawei, they assign the following product IDs
- * for all of their mobile broadband dongles,
- * including the new dongles in the future.
- * So if the product ID is not included in this list,
- * it means it is not Huawei's mobile broadband dongles.
- */
-static int usb_stor_hua

patch "tools: usb: ffs-test: Fix build failure" added to usb tree

2013-03-06 Thread gregkh

This is a note to let you know that I've just added the patch titled

tools: usb: ffs-test: Fix build failure

to my usb git tree which can be found at
git://git.kernel.org/pub/scm/linux/kernel/git/gregkh/usb.git
in the usb-linus branch.

The patch will show up in the next release of the linux-next tree
(usually sometime within the next 24 hours during the week.)

The patch will hopefully also be merged in Linus's tree for the
next -rc kernel release.

If you have any questions about this process, please let me know.


>From a0f11aceee531d444f58b939e6a537ee5e2b9cc5 Mon Sep 17 00:00:00 2001
From: "Maxin B. John" 
Date: Thu, 21 Feb 2013 01:57:51 +0200
Subject: tools: usb: ffs-test: Fix build failure

Fixes this build failure:
gcc -Wall -Wextra -g -lpthread -I../include -o testusb testusb.c
gcc -Wall -Wextra -g -lpthread -I../include -o ffs-test ffs-test.c
In file included from ffs-test.c:41:0:
../../include/linux/usb/functionfs.h:4:39: fatal error:
uapi/linux/usb/functionfs.h: No such file or directory
compilation terminated.
make: *** [ffs-test] Error 1

Signed-off-by: Maxin B. John 
Acked-by: Michal Nazarewicz 
Cc: stable   # 3.7+
Signed-off-by: Greg Kroah-Hartman 
---
 tools/usb/ffs-test.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

-- 
1.7.9.5

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH] remoteproc: properly fix missing CONFIG_FW_LOADER configurations

2013-03-06 Thread Paul Bolle
On Wed, 2013-03-06 at 14:32 +0200, Ohad Ben-Cohen wrote:
> Robert Tivy (cc'ed) already submitted a patch to this (it's part of a
> bigger series Robert is now polishing).

Great.

> Rob, it might indeed be a good idea to add "CC:
> stable@vger.kernel.org" to the commit log.

Thanks,


Paul Bolle

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH] remoteproc: properly fix missing CONFIG_FW_LOADER configurations

2013-03-06 Thread Ohad Ben-Cohen
Hi,

On Tue, Mar 5, 2013 at 9:20 PM, Paul Bolle  wrote:
> Fix obvious typo introduced in commit
> e121aefa7d9f10eee5cf26ed47129237a05d940b ("remoteproc: fix missing
> CONFIG_FW_LOADER configurations").

Robert Tivy (cc'ed) already submitted a patch to this (it's part of a
bigger series Robert is now polishing).

Rob, it might indeed be a good idea to add "CC:
stable@vger.kernel.org" to the commit log.

Thanks,
Ohad.
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH] remoteproc: properly fix missing CONFIG_FW_LOADER configurations

2013-03-06 Thread Greg KH
On Wed, Mar 06, 2013 at 08:53:22AM +0100, Paul Bolle wrote:
> On Wed, 2013-03-06 at 08:46 +0800, Greg KH wrote:
> > On Tue, Mar 05, 2013 at 11:22:49PM +0100, Paul Bolle wrote:
> > > 1) But actually thinking about this: that upstream commit did end up in
> > > the (longterm) v3.4.y series. And my patch is also relevant for the
> > > v3.8.y series.
> > 
> > As that patch was in the 3.5-rc7 release, how can it be relevant for
> > 3.8, or anything greater than 3.5 at all?
> 
> I seem to have confused you. My patch fixes a bug caused by a commit
> that shipped in final release v3.5 (and is also part the 3.4.y series,
> because that commit got added to that stable series).

What commit are you talking about here?  Please read
Documentation/stable_kernel_rules.txt for how to have a patch applied to
the stable kernel releases.

Hint, this isn't how you do it...

greg k-h
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH] pch_dma: Use GFP_ATOMIC because called from interrupt context

2013-03-06 Thread Tomoya MORINAGA
Hi Greg,

On Wed, Mar 6, 2013 at 4:04 PM, Greg KH  wrote:
>> commit:   4900b1396a629fa3e2c4e154d592e430dec3c804
>
> Where did you get that number from?  I don't see it in Linus's tree.

Sorry for my mistake.
I brought it from linux-next (below).

author  Tomoya MORINAGA  2013-02-12 02:25:33 (GMT)
committerVinod Koul   2013-03-04 04:58:01 
(GMT)
commit  4900b1396a629fa3e2c4e154d592e430dec3c804 (patch)
tree80c92fa08b75b5d7e9f23bb98eb3db83c1524c3c /drivers/dma/pch_dma.c
parent  76d1109b1355f9a7a81f07d6248b08eee3ee9386 (diff)
downloadlinux-next-4900b1396a629fa3e2c4e154d592e430dec3c804.tar.gz

I must have brought from Linus's.

>
>> Kernel version:   3.0 3.2 3.4 3.8 3.9
>
> Shouldn't this already be showing up in 3.9?
>
> totally confused,

I'm not sure whether this patch will be integrated to 3.9 or 3.10

Anyway, I'll resubmit the patch again.

Thanks,
-- 
ROHM Co., Ltd.
tomoya
--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: + dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present.patch added to -mm tree

2013-03-06 Thread Zhenzhong Duan

On 2013-03-06 07:37, a...@linux-foundation.org wrote:
> The patch titled
>  Subject: dmi_scan: fix missing check for _DMI_ signature in 
> smbios_present()
> has been added to the -mm tree.  Its filename is
>  dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present.patch
>
> Before you just go and hit "reply", please:
>a) Consider who else should be cc'ed
>b) Prefer to cc a suitable mailing list as well
>c) Ideally: find the original patch on the mailing list and do a
>   reply-to-all to that, adding suitable additional cc's
>
> *** Remember to use Documentation/SubmitChecklist when testing your code ***
>
> The -mm tree is included into linux-next and is updated
> there every 3-4 working days
>
> --
> From: Ben Hutchings 
> Subject: dmi_scan: fix missing check for _DMI_ signature in smbios_present()
>
> Commit 9f9c9cbb6057 ('drivers/firmware/dmi_scan.c: fetch dmi version from
> SMBIOS if it exists') hoisted the check for "_DMI_" into
> dmi_scan_machine(), which means that we don't bother to check for "_DMI_"
> at offset 16 in an SMBIOS entry.  smbios_present() may also call
> dmi_present() for an address where we found "_SM_", if it failed further
> validation.
>
> Check for "_DMI_" in smbios_present() before calling dmi_present().
>
> Signed-off-by: Ben Hutchings 
> Reported-by: Tim McGrath 
> Tested-by: Tim Mcgrath 
> Cc: Zhenzhong Duan 
> Cc: 
> Signed-off-by: Andrew Morton 
> ---
>
>  drivers/firmware/dmi_scan.c |5 ++---
>  1 file changed, 2 insertions(+), 3 deletions(-)
>
> diff -puN 
> drivers/firmware/dmi_scan.c~dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present
>  drivers/firmware/dmi_scan.c
> --- 
> a/drivers/firmware/dmi_scan.c~dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present
> +++ a/drivers/firmware/dmi_scan.c
> @@ -442,7 +442,6 @@ static int __init dmi_present(const char
>  static int __init smbios_present(const char __iomem *p)
>  {
>   u8 buf[32];
> - int offset = 0;
>  
>   memcpy_fromio(buf, p, 32);
>   if ((buf[5] < 32) && dmi_checksum(buf, buf[5])) {
> @@ -461,9 +460,9 @@ static int __init smbios_present(const c
>   dmi_ver = 0x0206;
>   break;
>   }
> - offset = 16;
> + return memcmp(q + 16, "_DMI_", 5) || dmi_present(p + 16);
>   }

I remember H.J found a typo in this patch and the following patch.
>The patch has a typo:
>
>-  offset = 16;
>+  return memcmp(q + 16, "_DMI_", 5) || dmi_present(p + 16);
>   }
>
>'q' isn't defined here.  Change it to `p" also fixes the problem for me.
>
>H.J.

> - return dmi_present(buf + offset);
> + return 1;
>  }
>  
>  void __init dmi_scan_machine(void)
> _
>
> Patches currently in -mm which might be from b...@decadent.org.uk are
>
> linux-next.patch
> dmi_scan-fix-missing-check-for-_dmi_-signature-in-smbios_present.patch
> dmi_scan-refactor-dmi_scan_machine-smbiosdmi_present.patch
>

--
To unsubscribe from this list: send the line "unsubscribe stable" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html